Skip to contents

Evaluates the automorphism at the given index on ct using the eval-key map returned by eval_automorphism_key_gen(). The result is a new ciphertext whose decrypted slot vector is a permutation of ct's slot vector (the permutation determined by the automorphism group element).

Usage

eval_automorphism(ct, index, eval_key_map)

Arguments

ct

A Ciphertext.

index

Integer; the automorphism index (must match one of the indices passed to eval_automorphism_key_gen()).

eval_key_map

An EvalKeyMap from eval_automorphism_key_gen().

Value

A transformed Ciphertext.