Integer m such that the underlying polynomial ring is
Z[x]/(x^n + 1) with n = m/2 (the ring dimension). Always
2 * ring_dimension(cc) for power-of-two cyclotomics.
Integer m such that the underlying polynomial ring is
Z[x]/(x^n + 1) with n = m/2 (the ring dimension). Always
2 * ring_dimension(cc) for power-of-two cyclotomics.